@@ -38,7 +38,7 @@ Settings::Settings(const QCommandLineParser &arg_parser)
 {
     if (QFileInfo::exists(
             QStringLiteral("/tmp/installed-to-live/cleanup.conf"))) // cleanup installed-to-live from other sessions
-        system("installed-to-live cleanup");
+        QProcess::execute("installed-to-live", {"cleanup"});
     shell = new Cmd;
 
     loadConfig(); // load settings from .conf file
@@ -87,7 +87,7 @@ bool Settings::checkSnapshotDir() const
         qDebug() << QObject::tr("Could not create working directory. ") + snapshot_dir;
         return false;
     }
-    system("chown $(logname):$(logname) \"/" + snapshot_dir.toUtf8() + "\"");
+    shell->run("chown $(logname):$(logname) \"/" + snapshot_dir + "\"", false);
     return true;
 }
 
@@ -121,7 +121,7 @@ QString Settings::getEditor() const
 {
     QString editor = gui_editor;
     if (editor.isEmpty()
-        || system("command -v " + editor.toUtf8()) != 0) { // if specified editor doesn't exist get the default one
+        || QProcess::execute("command", {"-v", editor}) != 0) { // if specified editor doesn't exist get the default one
         QString local = QDir::homePath() + "/.local/share/applications ";
         if (!QFile::exists(local))
             local = QLatin1String("");
@@ -225,7 +225,7 @@ void Settings::selectKernel()
         }
     }
     // Check if SQUASHFS is available
-    if (system("grep -q ^CONFIG_SQUASHFS=[ym] /boot/config-" + kernel.toUtf8()) != 0) {
+    if (QProcess::execute("grep", {"-q", "^CONFIG_SQUASHFS=[ym]", "/boot/config-" + kernel}) != 0) {
         QString message = QObject::tr("Current kernel doesn't support Squashfs, cannot continue.");
         if (qApp->metaObject()->className() != QLatin1String("QApplication"))
             qDebug().noquote() << message;
@@ -269,7 +269,7 @@ void Settings::setVariables()
     release_date = QDate::currentDate().toString(QStringLiteral("MMMM dd, yyyy"));
     codename = shell->getCmdOut(QStringLiteral("grep -oP '(?<=DISTRIB_CODENAME=).*' /etc/lsb-release"));
     codename.replace(QLatin1String("\""), QLatin1String(""));
-    boot_options = QStringLiteral("quiet");
+    boot_options = live ? readKernelOpts() : filterOptions(readKernelOpts());
 }
 
 // Create the output filename
@@ -665,6 +665,27 @@ void Settings::processExclArgs(const QCommandLineParser &arg_parser)
     }
 }
 
+// Read kernel line and options from /proc/cmdline
+QString Settings::readKernelOpts()
+{
+    QFile file(QStringLiteral("/proc/cmdline"));
+    if (!file.open(QIODevice::ReadOnly)) {
+        qDebug() << "Could not open file:" << file.fileName();
+        return QString();
+    }
+    return file.readAll();
+}
+
+QString Settings::filterOptions(QString options)
+{
+    options.remove(QRegularExpression("BOOT_IMAGE=\\S* ?"));
+    options.remove(QRegularExpression("initrd=\\S* ?"));
+    options.remove(QRegularExpression("init=\\S* ?"));
+    options.remove(QRegularExpression("root=\\S* ?"));
+    options.remove(QRegularExpression("\\bro ?\\b"));
+    return options.trimmed();
+}
+
 void Settings::setMonthlySnapshot(const QCommandLineParser &arg_parser)
 {
     QString name;
@@ -693,5 +714,6 @@ void Settings::setMonthlySnapshot(const QCommandLineParser &arg_parser)
     if (arg_parser.value(QStringLiteral("compression")).isEmpty())
         compression = QStringLiteral("zstd");
     reset_accounts = true;
+    boot_options.remove("toram");
     excludeAll();
 }
